#
# spec file for package xfconf
#
# Copyright (c) 2015 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


%define libname libxfconf-0-2
Name:           xfconf
Version:        4.12.1
Release:        lp150.1.5
Summary:        Simple Configuration Storage for Xfce
License:        GPL-2.0+
Group:          System/GUI/XFCE
Url:            http://www.xfce.org/projects#core
Source0:        http://archive.xfce.org/src/xfce/xfconf/4.12/%{name}-%{version}.tar.bz2
Source1:        xfconf-query.1
Source100:      %{name}-rpmlintrc
# PATCH-FIX-OPENSUSE xfconf-remove-rpath.patch gber@opensuse.org -- Do not set RPATH for Xfconf.so
Patch0:         xfconf-4.7.3-remove-rpath.patch
BuildRequires:  intltool
BuildRequires:  perl(ExtUtils::Depends)
BuildRequires:  perl(ExtUtils::PkgConfig)
BuildRequires:  perl(Glib)
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(dbus-glib-1)
BuildRequires:  pkgconfig(gobject-2.0)
BuildRequires:  pkgconfig(gtk-doc)
BuildRequires:  pkgconfig(libxfce4util-1.0) >= 4.9.0
Recommends:     %{name}-lang = %{version}
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
Xfconf is a simple client-server configuration storage and query system for the
Xfce desktop.

%package -n perl-xfconf
Summary:        Perl Interface to xfconf
Group:          Development/Libraries/Perl
Requires:       %{name} = %{version}
Requires:       perl = %{perl_version}
Requires:       perl(Glib)

%description -n perl-xfconf
This package contains the Perl interface to %{name}.

%package -n %{libname}
Summary:        xfconf Shared Library
Group:          System/Libraries
Recommends:     %{name} = %{version}
Provides:       libxfce4mcs = %{version}
Obsoletes:      libxfce4mcs < %{version}

%description -n %{libname}
This package contains the xfconf shared library.

%package -n libxfconf-devel
Summary:        Development Files for xfconf
Group:          Development/Libraries/C and C++
Requires:       %{libname} = %{version}
Provides:       libxfce4mcs-devel = %{version}
Obsoletes:      libxfce4mcs-devel < %{version}
Provides:       xfce-mcs-manager-devel = %{version}
Obsoletes:      xfce-mcs-manager-devel < %{version}

%description  -n libxfconf-devel
This package contains the files needed for developing applications using
xfconf.

# this should be replaced by %%lang_package once bnc#513786 is resolved
%package lang
Summary:        Languages for package %{name}
Group:          System/Localization
Requires:       %{libname} = %{version}
Provides:       %{name}-lang-all = %{version}
Supplements:    packageand(bundle-lang-other:%{libname})
BuildArch:      noarch

%description lang
Provides translations to the package %{name}

%prep
%setup -q
%patch0 -p1

%build
%configure \
    --disable-static \
    --with-helper-path-prefix=%{_libexecdir} \
    --with-perl-options='NOECHO= OPTIMIZE="%{optflags}" CCDLFLAGS="-Wl,-E" INSTALLDIRS=vendor' \
    --enable-gtk-doc
make %{?_smp_mflags} V=1

%install
%make_install
install -D -p -m 644 %{SOURCE1} %{buildroot}%{_mandir}/man1/xfconf-query.1

rm -f %{buildroot}%{_libdir}/*.la \
    %{buildroot}%{perl_vendorarch}/auto/Xfce4/Xfconf/Xfconf.bs

%perl_process_packlist

rm -rf %{buildroot}%{_datadir}/locale/{ast,kk,ur_PK}

%find_lang %{name} %{?no_lang_C}

%post -n %{libname} -p /sbin/ldconfig

%postun -n %{libname} -p /sbin/ldconfig

%files
%defattr(-,root,root)
%doc AUTHORS COPYING NEWS TODO
%{_bindir}/xfconf-query
%dir %{_libexecdir}/xfce4
%dir %{_libexecdir}/xfce4/xfconf
%{_libexecdir}/xfce4/xfconf/xfconfd
%{_datadir}/dbus-1/services/org.xfce.Xfconf.service
%doc %{_mandir}/man1/xfconf-query.1*

%files -n %{libname}
%defattr(-,root,root)
%doc COPYING
%{_libdir}/libxfconf-*.so.*

%files lang -f %{name}.lang
%defattr(-,root,root)

%files -n libxfconf-devel
%defattr(-,root,root)
%dir %{_datadir}/gtk-doc
%dir %{_datadir}/gtk-doc/html
%doc %{_datadir}/gtk-doc/html/xfconf
%{_includedir}/xfce4
%{_libdir}/libxfconf-*.so
%{_libdir}/pkgconfig/libxfconf-*.pc

%files -n perl-xfconf
%defattr(-,root,root)
%doc %{_mandir}/man3/Xfce4::Xfconf.3pm*
%dir %{perl_vendorarch}/Xfce4
%{perl_vendorarch}/Xfce4/Xfconf
%{perl_vendorarch}/Xfce4/Xfconf.pm
%dir %{perl_vendorarch}/auto
%dir %{perl_vendorarch}/auto/Xfce4
%{perl_vendorarch}/auto/Xfce4/Xfconf

%changelog
* Fri Sep 22 2017 seife+obs@b1-systems.com
- do not package ChangeLog, NEWS is enough
* Sat Nov 26 2016 seife+obs@b1-systems.com
- update to version 4.12.1
  - add support for binding to GdkRGBAs (needed for gtk3 migration)
  - translation updates
* Sat Feb 28 2015 gber@opensuse.org
- update to version 4.12.0
  - allow :.,[]{} characters in property and channel names
    (bxo#11021)
  - fix make check when including perl bindings in the build
    (bxo#9556)
  - remove unneeded files
  - drop deprecated g_type_init() function
  - simplify checks
  - autotools updates
  - use new glib 2.32 mutex api
  - translation updates
* Thu Feb 19 2015 gber@opensuse.org
- update to version 4.11.0
  - allow :.,[]{} characters in property and channel names
    (bxo#11021)
  - fix make check when including perl bindings in the build
    (bxo#9556)
  - remove unneeded files.
  - drop deprecated g_type_init() function
  - simplify checks
  - autotools updates
  - use new glib 2.32 mutex api
  - translation updates
* Wed May  9 2012 gber@opensuse.org
- add versioned build dependency
* Sun Apr 29 2012 gber@opensuse.org
- update to version 4.10.0
  - don't emit property-changed on canceled calls
  - accept NULL as a string value
  - check abicheck.sh to be more portable
  - fix more deprecated g_value_set_char
  - explicitly link against gthread
  - drop deprecated g_mapped_file_free
  - translation updates
* Sat Apr 14 2012 gber@opensuse.org
- update to version 4.9.1
  - use LT_PREREQ and LT_INIT
  - UTF-8 check xfconf strings
  - do not dup strings in xfconf_channel_set_string
  - bump package dependency versions
  - fix comment in perl package info
  - don't use deprecated g_value_set_char
  - translation updates
- added xfconf-query manpage from Debian
* Sun Apr  8 2012 gber@opensuse.org
- update to version 4.9.0
  - use sh as interpreter in tests
  - add hook to skip the xfconf tests
  - make the abicheck work on Solaris and PPC64
  - fix licenses and use new FSF address
  - fix compiler warnings on Solaris
  - avoid GCC 4.6 compiler warning
  - add toggle option to xfconf-query
  - remove unusable import and export options from xfconf-query
  - translate all error strings in xfconf-query
  - cleanup Makefile.am files a bit
  - improve --version output in xfconf-query
  - cleanup #includes
  - drop usage of the G_CONST_RETURN macro
  - translation updates
* Thu Mar 29 2012 gber@opensuse.org
- corrected dependencies
- split of -lang subpackage
- specfile cleanup
* Fri Dec 23 2011 gber@opensuse.org
- remove workarounds for 11.2
- update to version 4.8.1
  - fix double free crash
  - allow installation of the helpers in a custom location
  - translation updates
- install xfconfd under %%_libexecdir
* Mon Jan 17 2011 gber@opensuse.org
- update to version 4.8.0
  - updated translations
* Tue Jan 11 2011 gber@opensuse.org
- make libxfconf-0-2-4 recommend xfconf
* Mon Dec 27 2010 gber@opensuse.org
- remove unecessary dynloader bs file
- use perl symbol for perl dependencies
- corrected groups
- improved summaries/descriptions
- added rpmlintrc
* Wed Dec 15 2010 prusnak@opensuse.org
- build perl bindings only on openSUSE 11.3 and newer
* Sun Dec  5 2010 prusnak@opensuse.org
- updated to 4.7.4
  * Don't enable options with --disable-<option> (bug #6820).
  * Updated translations: ug, sk, pt.
* Wed Dec  1 2010 prusnak@opensuse.org
- use pkgconfig symbol in BuildRequires
* Tue Nov 23 2010 gber@opensuse.org
- updated to 4.7.3
  * Disable cache singletons and improve some code now we know the
    tree is always empty during prefetch. This is only a
    disadvantage when creating multiple new channels with the same
    name, but in that case channels singletons should be used.
  * Lots of memory leaks plugged. Valgrind log is clean now.
  * Fix memory corruption during file loading and use mmap.
  * Properly handle dirty channels in the daemon and avoid
    excessive saving of channels.
  * Disable unimplemented code in the properties cache.
  * Steal values during cache prefetch to avoid a lot of copying.
  * Updated translations: hu.
  * Remove dangling nodes from the tree after a recursive remove.
  * Use a seconds timeout to reduce system wakeups.
  * Only print debug messages when compiled with debugging.
  * Merge xml files in reversed order (bug #6079).
  * Use g_strcmp0 for comparing strings.
  * Bump glib depenency to 2.18.
  * Silent the build.
  * Updated translations: pt_BR, nl, gl, fi, ru.
- cleanup
  * added summaries and descriptions
  * fixed build of Perl interface
  * fixed dependencies
* Tue Feb  2 2010 prusnak@suse.cz
- updated to 4.7.1
  * Remove dangling nodes from the tree after a recursive remove.
  * Use a seconds timeout to reduce system wakeups.
  * Only print debug messages when compiled with debugging.
  * Merge xml files in reversed order (bug #6079).
  * Use g_strcmp0 for comparing strings.
  * Bump glib depenency to 2.18.
  * Silent the build.
  * Updated translations: pt_BR, nl, gl, fi, ru.
* Wed Jan 13 2010 prusnak@suse.cz
- updated to 4.7.0
  * Add prefetching and caching support to XfconfChannel. Should speed
    things up a bit on app startup, and avoid blocking waiting on DBus
    in other cases.
  * New simpler (internal) handling of property bindings.
  * Use new xdt macros, this requires xfce-dev-tools 4.7.2.
  * New tests for object bindings.
  * Updated translations: es, kk, ca, sv, hu, ro, gl, ja, cs, lv, ast,
    zh_CN, ur, ur_PK, da, eu, pt.
* Mon Jul 20 2009 dominique-obs@leuenberger.net
- Follow change of %%%%{_libexecdir}
* Mon Apr 27 2009 prusnak@suse.cz
- replaced libxfcegui4 with libxfce4util in BuildRequires
* Tue Apr 21 2009 prusnak@suse.cz
- updated to 4.6.1
* Mon Mar  9 2009 prusnak@suse.cz
- fix package names according to shared library policy
* Fri Feb 27 2009 prusnak@suse.cz
- updated to 4.6.0 (Xfce 4.6.0 release)
* Mon Aug 18 2008 prusnak@suse.cz
- created package (version 4.5.80)
